@@ -1,7 +1,7 @@
 package My::Nada;
 
-use Apache::RequestRec ();
-use Apache::Const -compile => 'OK';
+use Apache2::RequestRec ();
+use Apache2::Const -compile => 'OK';
 
 use strict;
 
@@ -11,14 +11,14 @@ sub print {
 
   $r->print('');
 
-  return Apache::OK;
+  return Apache2::Const::OK;
 }
 
 sub PRINT {
 
   print '';
 
-  return Apache::OK;
+  return Apache2::Const::OK;
 }
 
 1;
