@@ -1,8 +1,8 @@
 package My::Subrequest;
 
-use Apache::RequestRec ();
-use Apache::SubRequest ();
-use Apache::Const -compile => 'OK';
+use Apache2::RequestRec ();
+use Apache2::SubRequest ();
+use Apache2::Const -compile => 'OK';
 
 use Apache::IncludeHook;
 
@@ -15,7 +15,7 @@ sub handler {
   my $sub = $r->lookup_uri($uri);
   $sub->run;
 
-  return Apache::OK;
+  return Apache2::Const::OK;
 }
 
 1;
